package com.persagy.dmp.digital.client;

import com.persagy.dmp.basic.config.DigitalFeignConfig;
import com.persagy.dmp.basic.dto.RequestData;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.digital.entity.ObjectDigital;
import com.persagy.dmp.define.entity.ObjectTypeDefine;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;
import java.util.Set;

/***
 * Description:对象管理Client
 * @author : lijie
 * @date :2021/8/19 17:38
 * Update By lijie 2021/8/19 17:38
 */
@FeignClient(name = "dmp-rwd", configuration = DigitalFeignConfig.class,url = "${persagy.bdtp.rwd.service:}")
public interface DigitalObjectClient {

    /**
     * 根据项目id批量查询项目信息
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param projectIds: 项目id数组
     * @return 类型定义
     */
    @PostMapping("/rwd/instance/object/batchQueryProjectByIds")
    CommonResult<List<ObjectDigital>> batchQueryProjectByIds(
            @RequestParam("groupCode") String groupCode,
            @RequestParam("projectId") String projectId,
            @RequestParam("appId") String appId,
            @RequestParam("userId") String userId,
            @RequestBody Set<String> projectIds);

    /**
     * 根据管理分区id批量查询项目信息
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param requestData: 查询条件
     * @return 类型定义
     */
    @PostMapping("/rwd/instance/object/batchQueryProjectByGroupManageZoneIds")
    CommonResult<List<ObjectDigital>> batchQueryProjectByGroupManageZoneIds(
            @RequestParam("groupCode") String groupCode,
            @RequestParam("projectId") String projectId,
            @RequestParam("appId") String appId,
            @RequestParam("userId") String userId,
            @RequestBody RequestData requestData);
}
