package com.persagy.dmp.digital.client;

import cn.hutool.extra.spring.SpringUtil;
import com.persagy.dmp.basic.dto.RequestData;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.common.utils.ResultHelper;
import com.persagy.dmp.define.entity.ObjectTypeDefine;
import com.persagy.dmp.digital.entity.ObjectDigital;

import java.util.List;
import java.util.Set;

/**
 * 数据字典Client门面
 * @author Charlie Yu
 * @date 2021-05-15
 */
public class DigitalObjectFacade {

    private static DigitalObjectClient client = SpringUtil.getBean(DigitalObjectClient.class);

    /**
     * 根据项目id批量查询项目信息
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param projectIds: 项目id数组
     * @return 类型定义
     */
    public static List<ObjectDigital> batchQueryProjectByIds(String groupCode, String projectId, String appId,
                                                             String userId, Set<String> projectIds) {
        CommonResult<List<ObjectDigital>> result = client.batchQueryProjectByIds(groupCode, projectId, appId,
                userId, projectIds);
        return ResultHelper.getContent(result);
    }
    /**
     * 根据管理分区id批量查询项目信息
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param requestData: 请求参数
     * @return 类型定义
     */
    public static List<ObjectDigital> batchQueryProjectByGroupManageZoneIds(String groupCode, String projectId, String appId,
                                                             String userId, RequestData requestData) {
        CommonResult<List<ObjectDigital>> result = client.batchQueryProjectByGroupManageZoneIds(groupCode, projectId, appId,
                userId, requestData);
        return ResultHelper.getContent(result);
    }
}
